import { Construct } from 'constructs';
import { BaseStackProvider } from './BaseStackProvider';
import { ResourceContext } from '../spi/ResourceContext';
/**
 * Options for the DefaultStackProvider class.
 */
export interface DefaultStackProviderOptions {
    /**
     * Indicates whether to use the application name or not.
     * @default false
     */
    readonly useApplicationName?: boolean;
    /**
     * The name of the provider.
     */
    readonly providerName?: string;
}
/**
 * An abstract class that extends BaseStackProvider and provides default functionality
 * for registering and retrieving values in a stage store.
 */
export declare abstract class DefaultStackProvider extends BaseStackProvider {
    private static stageStore;
    private _stage?;
    private _appScope?;
    private _providerScope?;
    protected providerName: string;
    /**
     * Creates a new instance of the DefaultStackProvider class.
     * @param options The options for the provider.
     */
    constructor(options?: DefaultStackProviderOptions);
    /**
     * Provides resources based on the given context.
     * @param context The resource context.
     */
    provide(context: ResourceContext): void;
    private cleanup;
    /**
     * Registers a value in the stage store.
     * @param key The key to store the value under.
     * @param value The value to store.
     */
    register(key: string, value: any): void;
    /**
     * Retrieves a value from the stage store.
     * @param key The key to retrieve the value for.
     * @returns The stored value.
     * @throws {Error} If the value is not found.
     */
    get(key: string): any;
    /**
     * Returns the scope for the provider.
     * @returns The provider scope.
     */
    protected get scope(): Construct;
    /**
     * Resolves the value of an SSM parameter.
     * @param ssmParameterName The name of the SSM parameter.
     * @returns The resolved value of the SSM parameter.
     */
    resolve(ssmParameterName: string): string;
}
